**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name            Primal0
Sequence         1 - Introduction to mathematical programming using GAMS
Type             LP
GAMS language     Introduction to the GAMS language
Description
" A given farm can produce two crops: wheat and maize.
We are looking to determine the area dedicated to each crop, knowing that:
The farmer's objective is to maximize his income
The gross margin per hectare for wheat is 450 and for maize 1000.
Wheat requires 25 hours of labour per hectare and per year and maize 50 hours of labour .
The area of the farm is 50 ha and the farmer can work 2000 hours in a year.  "

$Offtext
*-----------------------------------------------------------------------------*


*----------                         DECLARATIONS                       ----------*
sets
C crops  /wheat,maize/
S state of nature      /S1*S5/
;


*----------                          DATA                        ----------*
scalar
LAND_A      land availability in hectares              /50/
Z0          minimum income                            /18000/
LABOUR_A    labour availability in hours             /2000/
;

parameter
WR(C) labour needs per hectare and per crop (hours)
/wheat   25
 maize   50/
;
table
GM(S,C) gross margin per crop (euros)
         wheat   maize
S1       460     2000
S2       440      500
S3       450      300
S4       450     1400
S5       470      800
;

parameter
p(s) probability of S
/S1 0.2
 S2 0.2
 S3 0.2
 S4 0.2
 S5 0.2/
;

parameter AGM(C) ;
AGM(C) = sum(S, GM(S,C)*p(S));
display AGM ;

*----------                         MODEL                          ----------*
 variables
Z    total farm income  (euros)
;

positive variables
RI random income by state of nature
X area per crop (hectares)
;

equations
OBJECTIVE       objective function
LAND            land equation
LABOUR          labour equation
RIC             income by state of nature calculation
safetyFirst(S)   contrainte de minimum de revenu
;

OBJECTIVE..  sum(c, AGM(c)*X(c)) =E= Z ;

LAND..       sum(c, X(c)) =l= LAND_A ;

LABOUR..     sum(c, WR(c)*X(c)) =L= LABOUR_A  ;

RIC(S)..     sum(c, GM(S,C)*X(C)) =e= RI(S) ;

safetyFirst(S)..   RI(S) =g= Z0 ;

model example first example /all/;

*----------                        SOLUTION                         ----------*
solve example using LP maximizing Z;



